public inbox for gentoo-commits@lists.gentoo.org
 help / color / mirror / Atom feed
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2020-10-18  8:29 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2020-10-18  8:29 UTC (permalink / raw
  To: gentoo-commits

commit:     d8affbd6c2a75c3acd8ecc5dbbad9224ecb43f94
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Sun Oct 18 08:21:36 2020 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Sun Oct 18 08:21:44 2020 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=d8affbd6

repoman: Update for a repoman-3.0.2 release

Signed-off-by: Zac Medico <zmedico <AT> gentoo.org>

 repoman/RELEASE-NOTES | 5 +++++
 repoman/setup.py      | 2 +-
 2 files changed, 6 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index f0b50cef6..a09845b79 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,11 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-3.0.2
+==================================
+* Bug Fixes:
+    - Bug 748144 Make file.size fatal for files larger than 20 KiB
+
 repoman-3.0.1
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index b2c5fd43f..a405e7816 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -448,7 +448,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '3.0.1',
+	version = '3.0.2',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2021-06-05 21:08 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2021-06-05 21:08 UTC (permalink / raw
  To: gentoo-commits

commit:     b18d15009ba91ce2603f298290fccbe94d519ced
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Sat Jun  5 20:55:20 2021 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Sat Jun  5 20:55:46 2021 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=b18d1500

repoman/setup.py: prefer setuptools over distutils (bug 794166)

Bug: https://bugs.gentoo.org/794166
Signed-off-by: Zac Medico <zmedico <AT> gentoo.org>

 repoman/setup.py | 40 +++++++++++++++++++++++++++-------------
 1 file changed, 27 insertions(+), 13 deletions(-)

diff --git a/repoman/setup.py b/repoman/setup.py
index 8a92ffff6..f8a019b24 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -1,19 +1,33 @@
 #!/usr/bin/env python
-# Copyright 1998-2020 Gentoo Authors
+# Copyright 1998-2021 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
-from distutils.core import setup, Command
-from distutils.command.build import build
-from distutils.command.build_scripts import build_scripts
-from distutils.command.clean import clean
-from distutils.command.install import install
-from distutils.command.install_data import install_data
-from distutils.command.install_lib import install_lib
-from distutils.command.install_scripts import install_scripts
-from distutils.command.sdist import sdist
-from distutils.dep_util import newer
-from distutils.dir_util import mkpath, remove_tree
-from distutils.util import change_root, subst_vars
+try:
+	from setuptools.core import setup, Command
+	from setuptools.command.build import build
+	from setuptools.command.build_scripts import build_scripts
+	from setuptools.command.clean import clean
+	from setuptools.command.install import install
+	from setuptools.command.install_data import install_data
+	from setuptools.command.install_lib import install_lib
+	from setuptools.command.install_scripts import install_scripts
+	from setuptools.command.sdist import sdist
+	from setuptools.dep_util import newer
+	from setuptools.dir_util import mkpath, remove_tree
+	from setuptools.util import change_root, subst_vars
+except ImportError:
+	from distutils.core import setup, Command
+	from distutils.command.build import build
+	from distutils.command.build_scripts import build_scripts
+	from distutils.command.clean import clean
+	from distutils.command.install import install
+	from distutils.command.install_data import install_data
+	from distutils.command.install_lib import install_lib
+	from distutils.command.install_scripts import install_scripts
+	from distutils.command.sdist import sdist
+	from distutils.dep_util import newer
+	from distutils.dir_util import mkpath, remove_tree
+	from distutils.util import change_root, subst_vars
 
 import codecs
 import collections


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2021-04-19  8:13 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2021-04-19  8:13 UTC (permalink / raw
  To: gentoo-commits

commit:     a6762ba01343311670579d98a39732b494454f18
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Mon Apr 19 07:51:38 2021 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Mon Apr 19 08:13:07 2021 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=a6762ba0

repoman/setup.py: update sdist for xz support

Signed-off-by: Zac Medico <zmedico <AT> gentoo.org>

 repoman/setup.py | 7 +++++--
 1 file changed, 5 insertions(+), 2 deletions(-)

diff --git a/repoman/setup.py b/repoman/setup.py
index e99189d06..8a92ffff6 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -337,10 +337,13 @@ class x_install_scripts(install_scripts):
 
 
 class x_sdist(sdist):
-	""" sdist defaulting to .tar.bz2 format, and archive files owned by root """
+	""" sdist defaulting to .tar.xz format, and archive files owned by root """
+
+	def initialize_options(self):
+		super().initialize_options()
+		self.formats = ['xztar']
 
 	def finalize_options(self):
-		self.formats = ['bztar']
 		if self.owner is None:
 			self.owner = 'root'
 		if self.group is None:


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2021-03-29  7:54 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2021-03-29  7:54 UTC (permalink / raw
  To: gentoo-commits

commit:     285d3ae987a079f32b909c6e6eddde9bc45a4a25
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Mon Mar 29 07:39:28 2021 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Mon Mar 29 07:45:59 2021 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=285d3ae9

repoman: Update for a repoman-3.0.3 release

Signed-off-by: Zac Medico <zmedico <AT> gentoo.org>

 repoman/RELEASE-NOTES | 6 ++++++
 repoman/setup.py      | 2 +-
 2 files changed, 7 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index a09845b79..df34803cc 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,12 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-3.0.3
+==================================
+* Bug Fixes:
+    - Bug 608664 variable.phase check like pkgcheck VariableScopeCheck
+    - Bug 692486 Change message for preserve_old_lib
+
 repoman-3.0.2
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index a405e7816..e99189d06 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -448,7 +448,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '3.0.2',
+	version = '3.0.3',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2020-08-19  5:43 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2020-08-19  5:43 UTC (permalink / raw
  To: gentoo-commits

commit:     fa69f697fbacc041df1264c61a9987baa14ff2a7
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Wed Aug 19 05:29:04 2020 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Wed Aug 19 05:38:03 2020 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=fa69f697

repoman: Update for a repoman-3.0.1 release

Signed-off-by: Zac Medico <zmedico <AT> gentoo.org>

 repoman/RELEASE-NOTES | 5 +++++
 repoman/setup.py      | 2 +-
 2 files changed, 6 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index 5769eac54..f0b50cef6 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,11 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-3.0.1
+==================================
+* Bug Fixes:
+    - Bug 737698 Update repoman for compatibility with portage-3.0.4.
+
 repoman-3.0.0
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index 6819de46d..b2c5fd43f 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -448,7 +448,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '3.0.0',
+	version = '3.0.1',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2020-08-17  6:13 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2020-08-17  6:13 UTC (permalink / raw
  To: gentoo-commits

commit:     ccff43b2a1a8a9c2a5a4917e19d4dee049c263df
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Mon Aug 17 05:45:41 2020 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Mon Aug 17 05:46:30 2020 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=ccff43b2

repoman: Update for a repoman-3.0.0 release

Signed-off-by: Zac Medico <zmedico <AT> gentoo.org>

 repoman/RELEASE-NOTES | 6 ++++++
 repoman/setup.py      | 2 +-
 2 files changed, 7 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index 0c79956a0..5769eac54 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,12 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-3.0.0
+==================================
+* Bug Fixes:
+    - Bug 448462 Add --jobs and --load-average options which allow
+      dependency checks for multiple profiles to run in parallel.
+
 repoman-2.3.23
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index 5fcfe12e6..6819de46d 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -448,7 +448,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.23',
+	version = '3.0.0',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2020-06-23  5:00 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2020-06-23  5:00 UTC (permalink / raw
  To: gentoo-commits

commit:     6bc3e9674f48d0ffb60c5ad0128276495c7dad3a
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Tue Jun 23 04:27:21 2020 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Tue Jun 23 04:59:23 2020 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=6bc3e967

repoman: Update for a repoman-2.3.23 release

Signed-off-by: Zac Medico <zmedico <AT> gentoo.org>

 repoman/RELEASE-NOTES | 5 +++++
 repoman/setup.py      | 2 +-
 2 files changed, 6 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index 80541fa5c..0c79956a0 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,11 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.23
+==================================
+* Bug Fixes:
+    - Bug 637824 Deprecate netsurf.eclass
+
 repoman-2.3.22
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index c3a7adad9..eae0e09fe 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -450,7 +450,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.22',
+	version = '2.3.23',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2020-03-25 20:57 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2020-03-25 20:57 UTC (permalink / raw
  To: gentoo-commits

commit:     ceee38b4b60d57c93774aae04abe4e70448054ac
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Wed Mar 25 20:49:51 2020 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Wed Mar 25 20:50:01 2020 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=ceee38b4

repoman: Update for a repoman-2.3.22 release

Signed-off-by: Zac Medico <zmedico <AT> gentoo.org>

 repoman/RELEASE-NOTES | 5 +++++
 repoman/setup.py      | 2 +-
 2 files changed, 6 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index 486c4f46c..80541fa5c 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,11 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.22
+==================================
+* Bug Fixes:
+    - Bug 712106 only stage changes in index for commit mode
+
 repoman-2.3.21
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index c3059003f..c3a7adad9 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -450,7 +450,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.21',
+	version = '2.3.22',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2020-03-15  2:09 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2020-03-15  2:09 UTC (permalink / raw
  To: gentoo-commits

commit:     8494160c57cbe38a2f2f7b3aa5b72eb4a122fdff
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Sun Mar 15 01:58:43 2020 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Sun Mar 15 01:58:56 2020 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=8494160c

repoman: Update for a repoman-2.3.21 release

Signed-off-by: Zac Medico <zmedico <AT> gentoo.org>

 repoman/RELEASE-NOTES | 6 ++++++
 repoman/setup.py      | 2 +-
 2 files changed, 7 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index 849cf6a42..486c4f46c 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,12 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.21
+==================================
+* Bug Fixes:
+    - Bug 712106 prevent spurious copyright header updates
+
+
 repoman-2.3.20
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index d8cf68a99..c3059003f 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -450,7 +450,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.20',
+	version = '2.3.21',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2019-12-06  7:55 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2019-12-06  7:55 UTC (permalink / raw
  To: gentoo-commits

commit:     a1bdfbffd155baa4b946d2ce52ffb2021f903b23
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Fri Dec  6 07:35:57 2019 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Fri Dec  6 07:36:04 2019 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=a1bdfbff

repoman-2.3.20

Signed-off-by: Zac Medico <zmedico <AT> gentoo.org>

 repoman/RELEASE-NOTES | 7 +++++++
 repoman/setup.py      | 2 +-
 2 files changed, 8 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index eaba6a1d7..849cf6a42 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,13 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.20
+==================================
+* Bug Fixes:
+    - Bug 541076 repoman commit: ignore unadded hidden files
+    - Bug 702100 repoman: support profiles/package.deprecated
+
+
 repoman-2.3.19
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index c265dbe75..d8cf68a99 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -450,7 +450,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.19',
+	version = '2.3.20',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2019-11-27  4:21 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2019-11-27  4:21 UTC (permalink / raw
  To: gentoo-commits

commit:     9ce78a6455cda58646694a61a287bf6f33704676
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Wed Nov 27 04:05:37 2019 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Wed Nov 27 04:05:51 2019 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=9ce78a64

repoman: Update for a repoman-2.3.19 release

Signed-off-by: Zac Medico <zmedico <AT> gentoo.org>

 repoman/RELEASE-NOTES | 7 +++++++
 repoman/setup.py      | 2 +-
 2 files changed, 8 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index dd6b1c6ac..eaba6a1d7 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,13 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.19
+==================================
+* Bug Fixes:
+    - Bug 667432 Rename DCO_SIGNED_OFF_BY config variable to SIGNED_OFF_BY.
+    - Bug 700456 Add --include-profiles=PROFILES
+
+
 repoman-2.3.18
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index fef1e9450..c265dbe75 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -450,7 +450,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.18',
+	version = '2.3.19',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2019-11-09  6:01 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2019-11-09  6:01 UTC (permalink / raw
  To: gentoo-commits

commit:     a78584964cdab8c3c7eb437c83688dacc04a5a8f
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Sat Nov  9 05:49:46 2019 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Sat Nov  9 05:50:52 2019 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=a7858496

repoman: Update for a repoman-2.3.18 release

Signed-off-by: Zac Medico <zmedico <AT> gentoo.org>

 repoman/RELEASE-NOTES | 8 ++++++++
 repoman/setup.py      | 2 +-
 2 files changed, 9 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index e252d0124..dd6b1c6ac 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,14 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.18
+==================================
+* Bug Fixes:
+    - Bug 690786 Support metadata/layout.conf restrict-allowed
+    - Bug 699514 Detect dosym absolute paths starting with ${D}, ${ED} etc.
+    - Bug 699508 Fix unsafe string interpolation.
+
+
 repoman-2.3.17
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index ebbf0a633..fef1e9450 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -450,7 +450,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.17',
+	version = '2.3.18',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2019-08-05  6:22 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2019-08-05  6:22 UTC (permalink / raw
  To: gentoo-commits

commit:     c11c239789bf7d9166cd1ecc55b0996b72c058f7
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Mon Aug  5 06:01:39 2019 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Mon Aug  5 06:01:39 2019 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=c11c2397

repoman: Update for a repoman-2.3.17 release

Signed-off-by: Zac Medico <zmedico <AT> gentoo.org>

 repoman/RELEASE-NOTES | 6 ++++++
 repoman/setup.py      | 2 +-
 2 files changed, 7 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index 6f6341748..e252d0124 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,12 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.17
+==================================
+* Bug Fixes:
+    - Bug 233589 Support PROPERTIES="live"
+
+
 repoman-2.3.16
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index c7bc29740..ebbf0a633 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -450,7 +450,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.16',
+	version = '2.3.17',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2019-06-23 18:20 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2019-06-23 18:20 UTC (permalink / raw
  To: gentoo-commits

commit:     5f8fc0259c4e88b12aad0eec2737df653d2a694b
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Sun Jun 23 17:39:23 2019 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Sun Jun 23 17:39:39 2019 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=5f8fc025

repoman: Update for a repoman-2.3.16 release

Signed-off-by: Zac Medico <zmedico <AT> gentoo.org>

 repoman/RELEASE-NOTES | 6 ++++++
 repoman/setup.py      | 2 +-
 2 files changed, 7 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index d6fc9ca3c..6f6341748 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,12 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.16
+==================================
+* Bug Fixes:
+    - Bug 687420 Allow empty LICENSE in acct-* packages for GLEP 81
+
+
 repoman-2.3.15
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index b0fa7fe20..c7bc29740 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -450,7 +450,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.15',
+	version = '2.3.16',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2019-06-20  1:18 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2019-06-20  1:18 UTC (permalink / raw
  To: gentoo-commits

commit:     fee6a8ba08a20f40047a7582fee51689ac79cb21
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Thu Jun 20 00:54:29 2019 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Thu Jun 20 00:54:49 2019 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=fee6a8ba

repoman: Update for a repoman-2.3.15 release

Signed-off-by: Zac Medico <zmedico <AT> gentoo.org>

 repoman/RELEASE-NOTES | 6 ++++++
 repoman/setup.py      | 2 +-
 2 files changed, 7 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index 39ab424d1..d6fc9ca3c 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,12 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.15
+==================================
+* Bug Fixes:
+    - Bug 688278 Accept 'Gentoo Foundation' copyright for old ebuilds
+
+
 repoman-2.3.14
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index 255961e4b..b0fa7fe20 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -450,7 +450,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.14',
+	version = '2.3.15',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2019-06-03 22:24 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2019-06-03 22:24 UTC (permalink / raw
  To: gentoo-commits

commit:     45bbad8ec3e57bba71656d530e78e62565d05119
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Mon Jun  3 22:10:51 2019 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Mon Jun  3 22:10:56 2019 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=45bbad8e

repoman: Update for a repoman-2.3.14 release

Signed-off-by: Zac Medico <zmedico <AT> gentoo.org>

 repoman/RELEASE-NOTES | 6 ++++++
 repoman/setup.py      | 2 +-
 2 files changed, 7 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index 235bb06fb..39ab424d1 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,12 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.14
+==================================
+* Bug Fixes:
+    - Bug 666330 Update for new copyright policy
+
+
 repoman-2.3.13
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index a8a7702d3..255961e4b 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -450,7 +450,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.13',
+	version = '2.3.14',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2019-05-26  7:56 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2019-05-26  7:56 UTC (permalink / raw
  To: gentoo-commits

commit:     a8850a872fc1fb63b57aa9daea89b34a21e9bfbc
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Sun May 26 07:31:27 2019 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Sun May 26 07:31:43 2019 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=a8850a87

repoman: Update for a repoman-2.3.13 release

Signed-off-by: Zac Medico <zmedico <AT> gentoo.org>

 repoman/RELEASE-NOTES | 5 +++++
 repoman/setup.py      | 2 +-
 2 files changed, 6 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index fa2c8b093..235bb06fb 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,11 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.13
+==================================
+* Bug Fixes:
+    - Bug 686074 report error for unknown arguments
+
 
 repoman-2.3.12
 ==================================

diff --git a/repoman/setup.py b/repoman/setup.py
index 642e86a71..a8a7702d3 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -450,7 +450,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.12',
+	version = '2.3.13',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2018-11-04  3:42 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2018-11-04  3:42 UTC (permalink / raw
  To: gentoo-commits

commit:     173bab752e823b37876c053d8dcb5202fe02ac39
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Sun Nov  4 03:10:56 2018 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Sun Nov  4 03:40:41 2018 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=173bab75

repoman: Update for a repoman-2.3.12 release

Signed-off-by: Zac Medico <zmedico <AT> gentoo.org>

 repoman/RELEASE-NOTES | 7 +++++++
 repoman/setup.py      | 2 +-
 2 files changed, 8 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index 920174ecf..fa2c8b093 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,13 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+
+repoman-2.3.12
+==================================
+* Bug Fixes:
+    - Bug 588752 fix exit code for manifest mode
+
+
 repoman-2.3.11
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index a18d6d0e3..642e86a71 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -450,7 +450,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.11',
+	version = '2.3.12',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2018-09-22  9:44 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2018-09-22  9:44 UTC (permalink / raw
  To: gentoo-commits

commit:     b84246ed16c7a2fe96075f456f64839d0536ae8f
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Sat Sep 22 09:08:19 2018 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Sat Sep 22 09:08:19 2018 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=b84246ed

repoman: Update for a repoman-2.3.11 release

 repoman/RELEASE-NOTES | 11 +++++++++++
 repoman/setup.py      |  2 +-
 2 files changed, 12 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index 47efd34bb..920174ecf 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,17 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.11
+==================================
+* Bug Fixes:
+    - Bug 666330 support new 'Gentoo Authors' copyright policy and
+      automatically apply the new policy when updating copyright headers.
+      Earlier versions of repoman will report an ebuild.badheader warning
+      for the new copyright headers. Users of earlier versions of repoman
+      should be advised to simply ignore the ebuild.badheader warning, or
+      else upgrade to the latest version of repoman.
+
+
 repoman-2.3.10
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index 23b106807..a18d6d0e3 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -450,7 +450,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.10',
+	version = '2.3.11',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2018-07-16  7:14 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2018-07-16  7:14 UTC (permalink / raw
  To: gentoo-commits

commit:     aca3e6d8720ecb94398c6ba4a3e0d5b3a304c9a7
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Mon Jul 16 06:45:50 2018 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Mon Jul 16 06:45:50 2018 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=aca3e6d8

repoman: Update for a repoman-2.3.10 release

 repoman/RELEASE-NOTES | 7 +++++++
 repoman/setup.py      | 2 +-
 2 files changed, 8 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index 12ddefc20..47efd34bb 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,13 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.10
+==================================
+* Bug Fixes:
+    - Bug 649482 warn about = deps without revision
+    - Bug 660982 populate implicit IUSE for empty profile
+
+
 repoman-2.3.8
 ==================================
 * The --experimental-repository-modules=<y|n> option enables a new

diff --git a/repoman/setup.py b/repoman/setup.py
index 16ee0bc63..23abff9b9 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -466,7 +466,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.9',
+	version = '2.3.10',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2018-03-30  7:00 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2018-03-30  7:00 UTC (permalink / raw
  To: gentoo-commits

commit:     25aad450a95bec2fb921a93b070ca68a1b8c1cf4
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Fri Mar 30 06:27:01 2018 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Fri Mar 30 06:39:22 2018 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=25aad450

repoman: Update for a repoman-2.3.9 release

 repoman/RELEASE-NOTES | 7 +++++++
 repoman/setup.py      | 2 +-
 2 files changed, 8 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index 42e66969e..12ddefc20 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,13 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.8
+==================================
+* The --experimental-repository-modules=<y|n> option enables a new
+  plugin modules system:
+  https://wiki.gentoo.org/wiki/Project:Portage/Repoman-Module-specs
+
+
 repoman-2.3.7
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index 5c58a9a51..3bb76ab8a 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -467,7 +467,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.8',
+	version = '2.3.9',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:repoman commit in: repoman/
@ 2018-03-30  5:20 Zac Medico
  2018-03-30  4:23 ` [gentoo-commits] proj/portage:master " Zac Medico
  0 siblings, 1 reply; 38+ messages in thread
From: Zac Medico @ 2018-03-30  5:20 UTC (permalink / raw
  To: gentoo-commits

commit:     8ef665c37ec1b76a2884903f9c29e5a2fffc3b97
Author:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
AuthorDate: Tue Dec  5 18:22:33 2017 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Fri Mar 30 03:51:22 2018 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=8ef665c3

repoman setup.py: Add the new cnf/qa_data cnf/linechecks items

Closes: https://github.com/gentoo/portage/pull/202

 repoman/setup.py | 2 ++
 1 file changed, 2 insertions(+)

diff --git a/repoman/setup.py b/repoman/setup.py
index aaf10cdb5..9ac58ef35 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -479,6 +479,8 @@ setup(
 
 	data_files = list(get_manpages()) + [
 		['$docdir', ['NEWS', 'RELEASE-NOTES']],
+		['share/repoman/qa_data', ['cnf/qa_data/qa_data.yaml']],
+		['share/repoman/linechecks', ['cnf/linechecks/linechecks.yaml']],
 	],
 
 	cmdclass = {


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2018-03-30  4:23 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2018-03-30  4:23 UTC (permalink / raw
  To: gentoo-commits

commit:     c281697cafe0fe76c634f349d762b5b9c0373bff
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Fri Mar 30 03:58:35 2018 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Fri Mar 30 03:58:58 2018 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=c281697c

repoman: Update for a repoman-2.3.8 release

 repoman/NEWS     | 5 +++++
 repoman/setup.py | 2 +-
 2 files changed, 6 insertions(+), 1 deletion(-)

diff --git a/repoman/NEWS b/repoman/NEWS
index 688c6c884..c8d22d024 100644
--- a/repoman/NEWS
+++ b/repoman/NEWS
@@ -1,5 +1,10 @@
 News (mainly features/major bug fixes)
 
+repoman 2.3.8
+=====================
+- Support for plugin module systems, see
+  https://wiki.gentoo.org/wiki/Project:Portage/Repoman-Module-specs
+
 repoman 2.3.0
 =====================
 - Final release

diff --git a/repoman/setup.py b/repoman/setup.py
index 9ac58ef35..89ef7d5d9 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -467,7 +467,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.7',
+	version = '2.3.8',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2018-03-28  7:52 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2018-03-28  7:52 UTC (permalink / raw
  To: gentoo-commits

commit:     9459ce0ff459ac262cc8b494c57c4b8299cfe4f3
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Wed Mar 28 07:38:24 2018 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Wed Mar 28 07:38:24 2018 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=9459ce0f

repoman: Update for a repoman-2.3.7 release

 repoman/RELEASE-NOTES | 6 ++++++
 repoman/setup.py      | 2 +-
 2 files changed, 7 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index 2e1464826..42e66969e 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,12 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.7
+==================================
+* Bug Fixes:
+    - Bug 552720 allow https for metadata.dtd URI
+
+
 repoman-2.3.6
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index c22a5c305..aaf10cdb5 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -467,7 +467,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.6',
+	version = '2.3.7',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2017-11-14 21:51 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2017-11-14 21:51 UTC (permalink / raw
  To: gentoo-commits

commit:     9daf32a376603ec889046411b55a24e4a01d0fe2
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Tue Nov 14 21:50:14 2017 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Tue Nov 14 21:50:14 2017 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=9daf32a3

repoman: Update for a repoman-2.3.6 release

 repoman/RELEASE-NOTES | 6 ++++++
 repoman/setup.py      | 2 +-
 2 files changed, 7 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index 6ec2d5f99..2e1464826 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,12 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.6
+==================================
+* Bug Fixes:
+    - Bug 637460 Fix import paths for unit tests
+
+
 repoman-2.3.5
 ==================================
 * Repository metadata/layout.conf supports manifest-required-hashes

diff --git a/repoman/setup.py b/repoman/setup.py
index ce0bc493a..c22a5c305 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -467,7 +467,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.5',
+	version = '2.3.6',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2017-11-14 21:46 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2017-11-14 21:46 UTC (permalink / raw
  To: gentoo-commits

commit:     4c4559f45b653a6b816ae66b1a6c4e7dd2ef7e8c
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Tue Nov 14 21:11:22 2017 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Tue Nov 14 21:14:13 2017 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=4c4559f4

repoman/setup.py: create pym -> lib symlink for unit tests (bug 637460)

Various code involving the .repoman_not_installed file assumes
that the 'pym' directory should be added to sys.path, therefore
create a pym -> lib symlink during unit tests.

Bug: https://bugs.gentoo.org/637460

 repoman/setup.py | 16 ++++++++++++++++
 1 file changed, 16 insertions(+)

diff --git a/repoman/setup.py b/repoman/setup.py
index 6411231e0..ce0bc493a 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -147,6 +147,11 @@ class x_clean(clean):
 			print('removing %s symlink' % repr(conf_dir))
 			os.unlink(conf_dir)
 
+		pym_dir = os.path.join(top_dir, 'pym')
+		if os.path.islink(pym_dir):
+			print('removing %s sylink' % repr(pym_dir))
+			os.unlink(pym_dir)
+
 		pni_file = os.path.join(top_dir, '.repoman_not_installed')
 		if os.path.exists(pni_file):
 			print('removing %s' % repr(pni_file))
@@ -393,6 +398,17 @@ class build_tests(x_build_scripts_custom):
 		print('Symlinking %s -> %s' % (conf_dir, conf_src))
 		os.symlink(conf_src, conf_dir)
 
+		# symlink 'pym' directory
+		pym_dir = os.path.join(self.top_dir, 'pym')
+		if os.path.exists(pym_dir):
+			if not os.path.islink(pym_dir):
+				raise SystemError('%s exists and is not a symlink (collision)'
+					% repr(pym_dir))
+			os.unlink(pym_dir)
+		pym_src = 'lib'
+		print('Symlinking %s -> %s' % (pym_dir, pym_src))
+		os.symlink(pym_src, pym_dir)
+
 		# create $build_lib/../.repoman_not_installed
 		# to enable proper paths in tests
 		with open(os.path.join(self.top_dir, '.repoman_not_installed'), 'w'):


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2017-11-14  5:02 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2017-11-14  5:02 UTC (permalink / raw
  To: gentoo-commits

commit:     f45b4973d64f6b8154eaa3a6b4b0b900ac33f1ce
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Tue Nov 14 04:45:20 2017 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Tue Nov 14 04:49:21 2017 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=f45b4973

repoman/setup.py: x_sdist default root owner for archive files

 repoman/setup.py | 6 +++++-
 1 file changed, 5 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index ad347cf11..6ec2d5f99 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,12 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.5
+==================================
+* Repository metadata/layout.conf supports manifest-required-hashes
+  attribute (default value is SHA512).
+
+
 repoman-2.3.4
 ==================================
 * Support two new options: --bug (-b) and --closes (-c)

diff --git a/repoman/setup.py b/repoman/setup.py
index eead1e299..6411231e0 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -451,7 +451,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.4',
+	version = '2.3.5',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2017-10-23 22:37 Brian Dolbec
  0 siblings, 0 replies; 38+ messages in thread
From: Brian Dolbec @ 2017-10-23 22:37 UTC (permalink / raw
  To: gentoo-commits

commit:     7b64f620c881a92b54fd4bfeb5d9ffe3f2b15d7d
Author:     Brian Dolbec <bdolbec <AT> gaikai <DOT> com>
AuthorDate: Mon Oct 23 22:27:51 2017 +0000
Commit:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
CommitDate: Mon Oct 23 22:35:54 2017 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=7b64f620

repoman: Update for a repoman release

Signed-off-by: Brian Dolbec <bdolbec <AT> gaikai.com>

 repoman/RELEASE-NOTES | 5 +++++
 repoman/setup.py      | 2 +-
 2 files changed, 6 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index 07fd62353..ad347cf11 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,11 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.4
+==================================
+* Support two new options: --bug (-b) and --closes (-c)
+
+
 repoman-2.3.3
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index 4a1283ec5..9c4def929 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -447,7 +447,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.3',
+	version = '2.3.4',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2017-07-18 23:08 Brian Dolbec
  0 siblings, 0 replies; 38+ messages in thread
From: Brian Dolbec @ 2017-07-18 23:08 UTC (permalink / raw
  To: gentoo-commits

commit:     4cfd3e5a9781efa5b2b50339a37b1d27a74f97d4
Author:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
AuthorDate: Tue Jul 18 18:46:13 2017 +0000
Commit:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
CommitDate: Tue Jul 18 18:49:52 2017 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=4cfd3e5a

repoman: Updates for a release

 repoman/RELEASE-NOTES | 12 ++++++++++++
 repoman/setup.py      |  2 +-
 2 files changed, 13 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index 96d7b2288..07fd62353 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,18 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.3
+==================================
+* Bug Fixes:
+    - Bug 571546 Change how the tmp file for the commit msg is made
+* flag URIs using http:// when https:// is available
+* Add a check for relative dosym candidates
+* Make all shebangs prefix friendly
+* Mark ruby-2.0 as deprecated
+* Detect inconsistent metadata.xml indentation
+* Warn about dropped keywords only for latest in SLOT.
+
+
 repoman-2.3.2
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index aaf76eab1..4a1283ec5 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -447,7 +447,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.2',
+	version = '2.3.3',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2017-03-01 22:45 Brian Dolbec
  0 siblings, 0 replies; 38+ messages in thread
From: Brian Dolbec @ 2017-03-01 22:45 UTC (permalink / raw
  To: gentoo-commits

commit:     6d7651b429956d91ee26b251cb7cbd983e4afd20
Author:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
AuthorDate: Wed Mar  1 22:38:35 2017 +0000
Commit:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
CommitDate: Wed Mar  1 22:39:17 2017 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=6d7651b4

repoman: Updates for a release

 repoman/RELEASE-NOTES | 18 ++++++++++++++++++
 repoman/setup.py      |  2 +-
 2 files changed, 19 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index c02e17fac..96d7b2288 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,24 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.2
+==================================
+* Bug Fixes:
+    - Bug 544938 add dev-qt/linguist-tools to RDEPEND.suspect set
+    - Bug 602002 make unused local USE flags an error
+    - Bug 533554 add HOMEPAGE.missingurischeme check
+    - Bug 610414 use regular expression to detect line continuations
+    - Bug 610954 Warn about stale CVS keywords in ebuild header
+    - Bug 611296 Don't update years in non-Gentoo copyright lines
+* Add virtual/linuxtv-dvb-headers to RDEPEND.suspect set
+* Add virtual/os-headers to RDEPEND.suspect set
+* Add gentoo to remote-id type
+* Define long for python3 Fixes: 006b168c1bb6
+* Commit footer improvements
+* Check for empty files in filesdir
+* Deprecate gpe.eclass, confutils.eclass
+
+
 repoman-2.3.1
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index 1c148c634..aaf76eab1 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -447,7 +447,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.1',
+	version = '2.3.2',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2017-03-01 22:18 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2017-03-01 22:18 UTC (permalink / raw
  To: gentoo-commits

commit:     7ee35c0615ca18903e478581e23ff4efbdb75a0a
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Wed Mar  1 22:16:56 2017 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Wed Mar  1 22:17:19 2017 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=7ee35c06

repoman/MANIFEST.in: include .repoman_not_installed

Suggested-by: Arfrever Frehtes Taifersar Arahesis <arfrever.fta <AT> gmail.com>

 repoman/MANIFEST.in | 1 +
 1 file changed, 1 insertion(+)

diff --git a/repoman/MANIFEST.in b/repoman/MANIFEST.in
index ed81a97db..d9ef2aee0 100644
--- a/repoman/MANIFEST.in
+++ b/repoman/MANIFEST.in
@@ -1,3 +1,4 @@
 
 # for the tests
 include cnf/metadata.xsd
+include .repoman_not_installed


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2016-12-12  1:30 Brian Dolbec
  0 siblings, 0 replies; 38+ messages in thread
From: Brian Dolbec @ 2016-12-12  1:30 UTC (permalink / raw
  To: gentoo-commits

commit:     e42272d57c1f0f5bbc3082c20ee20870a8abfe55
Author:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
AuthorDate: Mon Dec 12 00:40:44 2016 +0000
Commit:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
CommitDate: Mon Dec 12 00:41:38 2016 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=e42272d5

repoman: Final update to release-notes

 repoman/RELEASE-NOTES | 1 +
 1 file changed, 1 insertion(+)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index 756ca26..c02e17f 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -15,6 +15,7 @@ repoman-2.3.1
     - Disable SRC_URI.mirror warnings when there is only 1 mirror
     - Fix version output string to say Repoman, fix live versioning,
       add portage version to --version output.
+    - Add repoman version to "Package manager:" commit footer
 
 repoman-2.3.0
 ==================================


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2016-12-06  3:54 Brian Dolbec
  0 siblings, 0 replies; 38+ messages in thread
From: Brian Dolbec @ 2016-12-06  3:54 UTC (permalink / raw
  To: gentoo-commits

commit:     76700cee0a40758d1946896f62d3f8327a30ae80
Author:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
AuthorDate: Mon Dec  5 19:33:35 2016 +0000
Commit:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
CommitDate: Mon Dec  5 20:35:36 2016 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=76700cee

repoman: Updates for a release

 repoman/RELEASE-NOTES | 15 +++++++++++++++
 repoman/setup.py      |  2 +-
 2 files changed, 16 insertions(+), 1 deletion(-)

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index bf29686..756ca26 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,21 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.1
+==================================
+* Bug Fixes:
+    - Bug 586864 skip QA checks in manifest mode
+    - Bug 591184 fix erroneous LICENSE.syntax
+    - use https to fetch metadata.xsd
+    - update links to https
+    - Make LIVEVCS.* checks fatal
+    - fix _depend_checks baddepsyntax accounting
+    - Fix commitmessage assignment not being done
+    - Add cat/pkg: substtution in the commitsgfile text
+    - Disable SRC_URI.mirror warnings when there is only 1 mirror
+    - Fix version output string to say Repoman, fix live versioning,
+      add portage version to --version output.
+
 repoman-2.3.0
 ==================================
 * Bug Fixes:

diff --git a/repoman/setup.py b/repoman/setup.py
index 0d6d14f..dfa33fb 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -408,7 +408,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.0',
+	version = '2.3.1',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2016-06-23 18:01 Brian Dolbec
  0 siblings, 0 replies; 38+ messages in thread
From: Brian Dolbec @ 2016-06-23 18:01 UTC (permalink / raw
  To: gentoo-commits

commit:     644fee072ef7113cec3142ad7dd0fdea0ed06f3a
Author:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
AuthorDate: Thu Jun 23 16:46:21 2016 +0000
Commit:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
CommitDate: Thu Jun 23 16:48:33 2016 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=644fee07

Updates for release: repoman

 repoman/NEWS          | 4 ++++
 repoman/RELEASE-NOTES | 8 ++++++++
 repoman/setup.py      | 2 +-
 3 files changed, 13 insertions(+), 1 deletion(-)

diff --git a/repoman/NEWS b/repoman/NEWS
index 2b1325c..688c6c8 100644
--- a/repoman/NEWS
+++ b/repoman/NEWS
@@ -1,5 +1,9 @@
 News (mainly features/major bug fixes)
 
+repoman 2.3.0
+=====================
+- Final release
+
 repoman 2.3.0_rc1
 =====================
 - First test release

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
index b8ae8b3..bf29686 100644
--- a/repoman/RELEASE-NOTES
+++ b/repoman/RELEASE-NOTES
@@ -1,6 +1,14 @@
 Release Notes; upgrade information mainly.
 Features/major bugfixes are listed in NEWS
 
+repoman-2.3.0
+==================================
+* Bug Fixes:
+    - Bug 584786 Add support for .git as a file when --separate-git-dir is used
+    - Bug 585864 fix missing vcs_files_to_cps repodir argument
+    - Bug 585388 fix KeyError during manifest generation
+* New QA error: slot operator under '||' alternative
+
 repoman-2.3.0_rc1
 ==================================
 * Initial test release

diff --git a/repoman/setup.py b/repoman/setup.py
index 47ed155..0d6d14f 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -408,7 +408,7 @@ def get_manpages():
 
 setup(
 	name = 'repoman',
-	version = '2.3.0_rc1',
+	version = '2.3.0',
 	url = 'https://wiki.gentoo.org/wiki/Project:Portage',
 	author = 'Gentoo Portage Development Team',
 	author_email = 'dev-portage@gentoo.org',


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2016-05-15 23:51 Brian Dolbec
  0 siblings, 0 replies; 38+ messages in thread
From: Brian Dolbec @ 2016-05-15 23:51 UTC (permalink / raw
  To: gentoo-commits

commit:     28e4ea8c512c03fe95f83b6bafde6218f8a0c88b
Author:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
AuthorDate: Sat May 14 20:22:01 2016 +0000
Commit:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
CommitDate: Sat May 14 20:22:01 2016 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=28e4ea8c

repoman: Initial NEWS, RELEASE-NOTES files

 repoman/NEWS          | 5 +++++
 repoman/RELEASE-NOTES | 7 +++++++
 2 files changed, 12 insertions(+)

diff --git a/repoman/NEWS b/repoman/NEWS
new file mode 100644
index 0000000..2b1325c
--- /dev/null
+++ b/repoman/NEWS
@@ -0,0 +1,5 @@
+News (mainly features/major bug fixes)
+
+repoman 2.3.0_rc1
+=====================
+- First test release

diff --git a/repoman/RELEASE-NOTES b/repoman/RELEASE-NOTES
new file mode 100644
index 0000000..5daf588
--- /dev/null
+++ b/repoman/RELEASE-NOTES
@@ -0,0 +1,7 @@
+Release Notes; upgrade information mainly.
+Features/major bugfixes are listed in NEWS
+
+repoman-2.3.0_rc1
+==================================
+* initial release
+* Bug Fixes:


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:repoman commit in: repoman/
@ 2016-05-15 18:34 Brian Dolbec
  2016-05-15 23:51 ` [gentoo-commits] proj/portage:master " Brian Dolbec
  0 siblings, 1 reply; 38+ messages in thread
From: Brian Dolbec @ 2016-05-15 18:34 UTC (permalink / raw
  To: gentoo-commits

commit:     bc0d74d2933ab1716abbd85d0c9eae811e62b1c3
Author:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
AuthorDate: Sun May 15 00:21:33 2016 +0000
Commit:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
CommitDate: Sun May 15 18:17:03 2016 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=bc0d74d2

repoman: Fix the repoman/runtests script to run from it's current location

This allows it to be called from the base portage directory or anywhere else.

 repoman/runtests | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/repoman/runtests b/repoman/runtests
index bad83dc..599edda 100755
--- a/repoman/runtests
+++ b/repoman/runtests
@@ -121,6 +121,8 @@ def main(argv):
 			else:
 				pyversions.extend(ver.split())
 
+	here = os.path.dirname(__file__)
+	run_path = os.path.join(here, 'pym/repoman/tests/runTests.py')
 	tempdir = None
 	try:
 		# Set up a single tempdir for all the tests to use.
@@ -132,7 +134,7 @@ def main(argv):
 		statuses = []
 		for ver in pyversions:
 			prog = get_python_executable(ver)
-			cmd = [prog, '-b', '-Wd', 'pym/repoman/tests/runTests.py'] + args
+			cmd = [prog, '-b', '-Wd', run_path] + args
 			if os.access(prog, os.X_OK):
 				print('%sTesting with Python %s...%s' %
 					(colors.GOOD, ver, colors.NORMAL))


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:repoman commit in: repoman/
@ 2016-05-14 20:23 Brian Dolbec
  2016-05-15 23:51 ` [gentoo-commits] proj/portage:master " Brian Dolbec
  0 siblings, 1 reply; 38+ messages in thread
From: Brian Dolbec @ 2016-05-14 20:23 UTC (permalink / raw
  To: gentoo-commits

commit:     42697825e546990d80ffb38c12fecc3d9d372136
Author:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
AuthorDate: Sat May 14 20:21:26 2016 +0000
Commit:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
CommitDate: Sat May 14 20:21:26 2016 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=42697825

repoman/setup.py: Clean out unneeded code

 repoman/setup.py | 217 +------------------------------------------------------
 1 file changed, 1 insertion(+), 216 deletions(-)

diff --git a/repoman/setup.py b/repoman/setup.py
index 07b14dc..62c5b62 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -10,7 +10,6 @@ from distutils.command.build_scripts import build_scripts
 from distutils.command.clean import clean
 from distutils.command.install import install
 from distutils.command.install_data import install_data
-from distutils.command.install_lib import install_lib
 from distutils.command.install_scripts import install_scripts
 from distutils.command.sdist import sdist
 from distutils.dep_util import newer
@@ -19,10 +18,8 @@ from distutils.util import change_root, subst_vars
 
 import codecs
 import collections
-import glob
 import os
 import os.path
-import re
 import subprocess
 import sys
 
@@ -34,8 +31,6 @@ x_scripts = {
 	'bin': [
 		'bin/repoman',
 	],
-	'sbin': [
-	],
 }
 
 
@@ -83,113 +78,6 @@ class build_man(Command):
 					f.writelines(data)
 
 
-class docbook(Command):
-	""" Build docs using docbook. """
-
-	user_options = [
-		('doc-formats=', None, 'Documentation formats to build (all xmlto formats for docbook are allowed, comma-separated'),
-	]
-
-	def initialize_options(self):
-		self.doc_formats = 'xhtml,xhtml-nochunks'
-
-	def finalize_options(self):
-		self.doc_formats = self.doc_formats.replace(',', ' ').split()
-
-	def run(self):
-		if not os.path.isdir('doc/fragment'):
-			mkpath('doc/fragment')
-
-		with open('doc/fragment/date', 'w'):
-			pass
-		with open('doc/fragment/version', 'w') as f:
-			f.write('<releaseinfo>%s</releaseinfo>' % self.distribution.get_version())
-
-		for f in self.doc_formats:
-			print('Building docs in %s format...' % f)
-			subprocess.check_call(['xmlto', '-o', 'doc',
-				'-m', 'doc/custom.xsl', f, 'doc/portage.docbook'])
-
-
-class epydoc(Command):
-	""" Build API docs using epydoc. """
-
-	user_options = [
-	]
-
-	def initialize_options(self):
-		self.build_lib = None
-
-	def finalize_options(self):
-		self.set_undefined_options('build_py', ('build_lib', 'build_lib'))
-
-	def run(self):
-		self.run_command('build_py')
-
-		print('Building API documentation...')
-
-		process_env = os.environ.copy()
-		pythonpath = self.build_lib
-		try:
-			pythonpath += ':' + process_env['PYTHONPATH']
-		except KeyError:
-			pass
-		process_env['PYTHONPATH'] = pythonpath
-
-		subprocess.check_call(['epydoc', '-o', 'epydoc',
-			'--name', self.distribution.get_name(),
-			'--url', self.distribution.get_url(),
-			'-qq', '--no-frames', '--show-imports',
-			'--exclude', 'portage.tests',
-			'_emerge', 'portage'],
-			env = process_env)
-		os.remove('epydoc/api-objects.txt')
-
-
-class install_docbook(install_data):
-	""" install_data for docbook docs """
-
-	user_options = install_data.user_options
-
-	def initialize_options(self):
-		install_data.initialize_options(self)
-		self.htmldir = None
-
-	def finalize_options(self):
-		self.set_undefined_options('install', ('htmldir', 'htmldir'))
-		install_data.finalize_options(self)
-
-	def run(self):
-		if not os.path.exists('doc/portage.html'):
-			self.run_command('docbook')
-		self.data_files = [
-			(self.htmldir, glob.glob('doc/*.html')),
-		]
-		install_data.run(self)
-
-
-class install_epydoc(install_data):
-	""" install_data for epydoc docs """
-
-	user_options = install_data.user_options
-
-	def initialize_options(self):
-		install_data.initialize_options(self)
-		self.htmldir = None
-
-	def finalize_options(self):
-		self.set_undefined_options('install', ('htmldir', 'htmldir'))
-		install_data.finalize_options(self)
-
-	def run(self):
-		if not os.path.exists('epydoc/index.html'):
-			self.run_command('epydoc')
-		self.data_files = [
-			(os.path.join(self.htmldir, 'api'), glob.glob('epydoc/*')),
-		]
-		install_data.run(self)
-
-
 class x_build_scripts_custom(build_scripts):
 	def finalize_options(self):
 		build_scripts.finalize_options(self)
@@ -225,14 +113,6 @@ class x_build_scripts_bin(x_build_scripts_custom):
 	dir_name = 'bin'
 
 
-class x_build_scripts_sbin(x_build_scripts_custom):
-	dir_name = 'sbin'
-
-
-class x_build_scripts_portagebin(x_build_scripts_custom):
-	dir_name = 'portage'
-
-
 class x_build_scripts(build_scripts):
 	def initialize_option(self):
 		build_scripts.initialize_options(self)
@@ -242,37 +122,11 @@ class x_build_scripts(build_scripts):
 
 	def run(self):
 		self.run_command('build_scripts_bin')
-		self.run_command('build_scripts_portagebin')
-		self.run_command('build_scripts_sbin')
 
 
 class x_clean(clean):
 	""" clean extended for doc & post-test cleaning """
 
-	@staticmethod
-	def clean_docs():
-		def get_doc_outfiles():
-			for dirpath, _dirnames, filenames in os.walk('doc'):
-				for f in filenames:
-					if f.endswith('.docbook') or f == 'custom.xsl':
-						pass
-					else:
-						yield os.path.join(dirpath, f)
-
-				# do not recurse
-				break
-
-
-		for f in get_doc_outfiles():
-			print('removing %s' % repr(f))
-			os.remove(f)
-
-		if os.path.isdir('doc/fragment'):
-			remove_tree('doc/fragment')
-
-		if os.path.isdir('epydoc'):
-			remove_tree('epydoc')
-
 	def clean_tests(self):
 		# do not remove incorrect dirs accidentally
 		top_dir = os.path.normpath(os.path.join(self.build_lib, '..'))
@@ -410,54 +264,6 @@ class x_install_data(install_data):
 		self.data_files = old_data_files
 
 
-class x_install_lib(install_lib):
-	""" install_lib command with Portage path substitution """
-
-	user_options = install_lib.user_options
-
-	def initialize_options(self):
-		install_lib.initialize_options(self)
-		self.portage_base = None
-		self.portage_bindir = None
-		self.portage_confdir = None
-
-	def finalize_options(self):
-		install_lib.finalize_options(self)
-		self.set_undefined_options('install',
-			('portage_base', 'portage_base'),
-			('portage_bindir', 'portage_bindir'),
-			('portage_confdir', 'portage_confdir'))
-
-	def install(self):
-		ret = install_lib.install(self)
-
-		def rewrite_file(path, val_dict):
-			path = os.path.join(self.install_dir, path)
-			print('Rewriting %s' % path)
-			with codecs.open(path, 'r', 'utf-8') as f:
-				data = f.read()
-
-			for varname, val in val_dict.items():
-				regexp = r'(?m)^(%s\s*=).*$' % varname
-				repl = r'\1 %s' % repr(val)
-
-				data = re.sub(regexp, repl, data)
-
-			with codecs.open(path, 'w', 'utf-8') as f:
-				f.write(data)
-
-		rewrite_file('portage/__init__.py', {
-			'VERSION': self.distribution.get_version(),
-		})
-		rewrite_file('portage/const.py', {
-			'PORTAGE_BASE_PATH': self.portage_base,
-			'PORTAGE_BIN_PATH': self.portage_bindir,
-			'PORTAGE_CONFIG_PATH': self.portage_confdir,
-		})
-
-		return ret
-
-
 class x_install_scripts_custom(install_scripts):
 	def initialize_options(self):
 		install_scripts.initialize_options(self)
@@ -480,16 +286,6 @@ class x_install_scripts_bin(x_install_scripts_custom):
 	var_name = 'bindir'
 
 
-class x_install_scripts_sbin(x_install_scripts_custom):
-	dir_name = 'sbin'
-	var_name = 'sbindir'
-
-
-class x_install_scripts_portagebin(x_install_scripts_custom):
-	dir_name = 'portage'
-	var_name = 'portage_bindir'
-
-
 class x_install_scripts(install_scripts):
 	def initialize_option(self):
 		pass
@@ -499,8 +295,6 @@ class x_install_scripts(install_scripts):
 
 	def run(self):
 		self.run_command('install_scripts_bin')
-		self.run_command('install_scripts_portagebin')
-		self.run_command('install_scripts_sbin')
 
 
 class x_sdist(sdist):
@@ -576,7 +370,7 @@ class test(Command):
 		self.run_command('build_tests')
 		subprocess.check_call([
 			sys.executable, '-bWd',
-			os.path.join(self.build_lib, 'portage/tests/runTests.py')
+			os.path.join(self.build_lib, 'repoman/tests/runTests.py')
 		])
 
 
@@ -631,21 +425,12 @@ setup(
 		'build_man': build_man,
 		'build_scripts': x_build_scripts,
 		'build_scripts_bin': x_build_scripts_bin,
-		'build_scripts_portagebin': x_build_scripts_portagebin,
-		'build_scripts_sbin': x_build_scripts_sbin,
 		'build_tests': build_tests,
 		'clean': x_clean,
-		'docbook': docbook,
-		'epydoc': epydoc,
 		'install': x_install,
 		'install_data': x_install_data,
-		'install_docbook': install_docbook,
-		'install_epydoc': install_epydoc,
-		'install_lib': x_install_lib,
 		'install_scripts': x_install_scripts,
 		'install_scripts_bin': x_install_scripts_bin,
-		'install_scripts_portagebin': x_install_scripts_portagebin,
-		'install_scripts_sbin': x_install_scripts_sbin,
 		'sdist': x_sdist,
 		'test': test,
 	},


^ permalink raw reply related	[flat|nested] 38+ messages in thread

end of thread, other threads:[~2021-06-05 21:08 UTC | newest]

Thread overview: 38+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2020-10-18  8:29 [gentoo-commits] proj/portage:master commit in: repoman/ Zac Medico
  -- strict thread matches above, loose matches on Subject: below --
2021-06-05 21:08 Zac Medico
2021-04-19  8:13 Zac Medico
2021-03-29  7:54 Zac Medico
2020-08-19  5:43 Zac Medico
2020-08-17  6:13 Zac Medico
2020-06-23  5:00 Zac Medico
2020-03-25 20:57 Zac Medico
2020-03-15  2:09 Zac Medico
2019-12-06  7:55 Zac Medico
2019-11-27  4:21 Zac Medico
2019-11-09  6:01 Zac Medico
2019-08-05  6:22 Zac Medico
2019-06-23 18:20 Zac Medico
2019-06-20  1:18 Zac Medico
2019-06-03 22:24 Zac Medico
2019-05-26  7:56 Zac Medico
2018-11-04  3:42 Zac Medico
2018-09-22  9:44 Zac Medico
2018-07-16  7:14 Zac Medico
2018-03-30  7:00 Zac Medico
2018-03-30  5:20 [gentoo-commits] proj/portage:repoman " Zac Medico
2018-03-30  4:23 ` [gentoo-commits] proj/portage:master " Zac Medico
2018-03-30  4:23 Zac Medico
2018-03-28  7:52 Zac Medico
2017-11-14 21:51 Zac Medico
2017-11-14 21:46 Zac Medico
2017-11-14  5:02 Zac Medico
2017-11-14  5:02 Zac Medico
2017-10-23 22:37 Brian Dolbec
2017-07-18 23:08 Brian Dolbec
2017-03-01 22:45 Brian Dolbec
2017-03-01 22:18 Zac Medico
2016-12-12  1:30 Brian Dolbec
2016-12-06  3:54 Brian Dolbec
2016-06-23 18:01 Brian Dolbec
2016-05-15 23:51 Brian Dolbec
2016-05-15 18:34 [gentoo-commits] proj/portage:repoman " Brian Dolbec
2016-05-15 23:51 ` [gentoo-commits] proj/portage:master " Brian Dolbec
2016-05-14 20:23 [gentoo-commits] proj/portage:repoman " Brian Dolbec
2016-05-15 23:51 ` [gentoo-commits] proj/portage:master " Brian Dolbec

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
diff --git a/repoman/setup.py b/repoman/setup.py
index 9c4def929..eead1e299 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -339,11 +339,15 @@ class x_install_scripts(install_scripts):
 
 
 class x_sdist(sdist):
 	""" sdist defaulting to .tar.bz2 format """
 
 	def finalize_options(self):
 		if self.formats is None:
 			self.formats = ['bztar']
+		if self.owner is None:
+			self.owner = 'root'
+		if self.group is None:
+			self.group = 'root'
 
 		sdist.finalize_options(self)
 


^ permalink raw reply related	[flat|nested] 38+ messages in thread
* [gentoo-commits] proj/portage:master commit in: repoman/
@ 2017-11-14  5:02 Zac Medico
  0 siblings, 0 replies; 38+ messages in thread
From: Zac Medico @ 2017-11-14  5:02 UTC (permalink / raw
  To: gentoo-commits
@@ -339,11 +339,15 @@ class x_install_scripts(install_scripts):
 
 class x_sdist(sdist):
-	""" sdist defaulting to .tar.bz2 format """
+	""" sdist defaulting to .tar.bz2 format, and archive files owned by root """
 
 	def finalize_options(self):

commit:     c8376d98b984d4040559da5628fb012a2be1d91a
Author:     Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Tue Nov 14 04:51:22 2017 +0000
Commit:     Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Tue Nov 14 05:02:07 2017 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=c8376d98

repoman: Update for a repoman-2.3.5 release

 repoman/RELEASE-NOTES | 6 ++++++
 repoman/setup.py      | 2 +-
 2 files changed, 7 insertions(+), 1 deletion(-)
